# vision

[![PyPI][pypi-badge]][pypi-link]
[![GitHub issues][issue-badge]][issue-link]
[![GitHub forks][fork-badge]][fork-link]
[![GitHub stars][star-badge]][star-link]
[![GitHub license][license-badge]][license-link]
[![contributors][contributor-badge]][contributor-link]
[![watcher][watcher-badge]][watcher-link]
[![Binder][binder-badge]][binder-link]
[![Downloads][download-badge]][download-link]
[![Documentation Status][status-badge]][status-link]
[![PyPI - Downloads][install-badge]][install-link]
![repo size](https://img.shields.io/github/repo-size/xinetzone/vision.svg)


学无止境！

[pypi-badge]: https://img.shields.io/pypi/v/visionz.svg
[pypi-link]: https://pypi.org/project/visionz/
[issue-badge]: https://img.shields.io/github/issues/xinetzone/vision
[issue-link]: https://github.com/xinetzone/vision/issues
[fork-badge]: https://img.shields.io/github/forks/xinetzone/vision
[fork-link]: https://github.com/xinetzone/vision/network
[star-badge]: https://img.shields.io/github/stars/xinetzone/vision
[star-link]: https://github.com/xinetzone/vision/stargazers
[license-badge]: https://img.shields.io/github/license/xinetzone/vision
[license-link]: https://github.com/xinetzone/vision/LICENSE
[contributor-badge]: https://img.shields.io/github/contributors/xinetzone/vision
[contributor-link]: https://github.com/xinetzone/vision/contributors
[watcher-badge]: https://img.shields.io/github/watchers/xinetzone/vision
[watcher-link]: https://github.com/xinetzone/vision/watchers
[binder-badge]: https://mybinder.org/badge_logo.svg
[binder-link]: https://mybinder.org/v2/gh/xinetzone/vision/main
[install-badge]: https://img.shields.io/pypi/dw/visionz?label=pypi%20installs
[install-link]: https://pypistats.org/packages/visionz
[status-badge]: https://readthedocs.org/projects/vision/badge/?version=latest
[status-link]: https://vision.readthedocs.io/zh/latest/?badge=latest
[download-badge]: https://pepy.tech/badge/visionz
[download-link]: https://pepy.tech/project/visionz

## 支持 PyPI

需要安装 `vision` 包：

```shell
pip install vision
```
